# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/data/v1beta1/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/data/v1beta1/data_source.proto',
  package='protopia.cloud.governance.v1beta1',
  syntax='proto3',
  serialized_options=b'Z<github.com/protopia-ai/cloud/pkg/api/data/v1beta1;datasource',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+protopia/api/data/v1beta1/data_source.proto\x12!protopia.cloud.governance.v1beta1\x1a google/protobuf/field_mask.proto\";\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x8e\x01\n\x17UpdateDataSourceRequest\x12\x42\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32-.protopia.cloud.governance.v1beta1.DataSource\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"%\n\x17\x44\x65leteDataSourceRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"?\n\x16ListDataSourcesRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"w\n\x17ListDataSourcesResponse\x12\x43\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32-.protopia.cloud.governance.v1beta1.DataSource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\"\n\x14GetDataSourceRequest\x12\n\n\x02id\x18\x01 \x01(\t2\x96\x05\n\x11\x44\x61taSourceService\x12p\n\x10\x43reateDatasource\x12-.protopia.cloud.governance.v1beta1.DataSource\x1a-.protopia.cloud.governance.v1beta1.DataSource\x12\x88\x01\n\x0fListDataSources\x12\x39.protopia.cloud.governance.v1beta1.ListDataSourcesRequest\x1a:.protopia.cloud.governance.v1beta1.ListDataSourcesResponse\x12w\n\rGetDataSource\x12\x37.protopia.cloud.governance.v1beta1.GetDataSourceRequest\x1a-.protopia.cloud.governance.v1beta1.DataSource\x12}\n\x10UpdateDatasource\x12:.protopia.cloud.governance.v1beta1.UpdateDataSourceRequest\x1a-.protopia.cloud.governance.v1beta1.DataSource\x12\x8b\x01\n\x10\x44\x65leteDatasource\x12:.protopia.cloud.governance.v1beta1.DeleteDataSourceRequest\x1a;.protopia.cloud.governance.v1beta1.DeleteDataSourceResponseB>Z<github.com/protopia-ai/cloud/pkg/api/data/v1beta1;datasourceb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_DATASOURCE = _descriptor.Descriptor(
  name='DataSource',
  full_name='protopia.cloud.governance.v1beta1.DataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.governance.v1beta1.DataSource.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.governance.v1beta1.DataSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='protopia.cloud.governance.v1beta1.DataSource.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=175,
)


_UPDATEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='UpdateDataSourceRequest',
  full_name='protopia.cloud.governance.v1beta1.UpdateDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source', full_name='protopia.cloud.governance.v1beta1.UpdateDataSourceRequest.data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='protopia.cloud.governance.v1beta1.UpdateDataSourceRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=320,
)


_DELETEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='DeleteDataSourceRequest',
  full_name='protopia.cloud.governance.v1beta1.DeleteDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.governance.v1beta1.DeleteDataSourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=359,
)


_DELETEDATASOURCERESPONSE = _descriptor.Descriptor(
  name='DeleteDataSourceResponse',
  full_name='protopia.cloud.governance.v1beta1.DeleteDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=387,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
  name='ListDataSourcesRequest',
  full_name='protopia.cloud.governance.v1beta1.ListDataSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=452,
)


_LISTDATASOURCESRESPONSE = _descriptor.Descriptor(
  name='ListDataSourcesResponse',
  full_name='protopia.cloud.governance.v1beta1.ListDataSourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_sources', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesResponse.data_sources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=573,
)


_GETDATASOURCEREQUEST = _descriptor.Descriptor(
  name='GetDataSourceRequest',
  full_name='protopia.cloud.governance.v1beta1.GetDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.governance.v1beta1.GetDataSourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=609,
)

_UPDATEDATASOURCEREQUEST.fields_by_name['data_source'].message_type = _DATASOURCE
_UPDATEDATASOURCEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTDATASOURCESRESPONSE.fields_by_name['data_sources'].message_type = _DATASOURCE
DESCRIPTOR.message_types_by_name['DataSource'] = _DATASOURCE
DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest'] = _UPDATEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataSourceRequest'] = _DELETEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataSourceResponse'] = _DELETEDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['ListDataSourcesRequest'] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListDataSourcesResponse'] = _LISTDATASOURCESRESPONSE
DESCRIPTOR.message_types_by_name['GetDataSourceRequest'] = _GETDATASOURCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

DeleteDataSourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.DeleteDataSourceRequest)
  })
_sym_db.RegisterMessage(DeleteDataSourceRequest)

DeleteDataSourceResponse = _reflection.GeneratedProtocolMessageType('DeleteDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCERESPONSE,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.DeleteDataSourceResponse)
  })
_sym_db.RegisterMessage(DeleteDataSourceResponse)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType('ListDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.ListDataSourcesRequest)
  })
_sym_db.RegisterMessage(ListDataSourcesRequest)

ListDataSourcesResponse = _reflection.GeneratedProtocolMessageType('ListDataSourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESRESPONSE,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.ListDataSourcesResponse)
  })
_sym_db.RegisterMessage(ListDataSourcesResponse)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)


DESCRIPTOR._options = None

_DATASOURCESERVICE = _descriptor.ServiceDescriptor(
  name='DataSourceService',
  full_name='protopia.cloud.governance.v1beta1.DataSourceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=612,
  serialized_end=1274,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDatasource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.CreateDatasource',
    index=0,
    containing_service=None,
    input_type=_DATASOURCE,
    output_type=_DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataSources',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.ListDataSources',
    index=1,
    containing_service=None,
    input_type=_LISTDATASOURCESREQUEST,
    output_type=_LISTDATASOURCESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataSource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.GetDataSource',
    index=2,
    containing_service=None,
    input_type=_GETDATASOURCEREQUEST,
    output_type=_DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDatasource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.UpdateDatasource',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATASOURCEREQUEST,
    output_type=_DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDatasource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.DeleteDatasource',
    index=4,
    containing_service=None,
    input_type=_DELETEDATASOURCEREQUEST,
    output_type=_DELETEDATASOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASOURCESERVICE)

DESCRIPTOR.services_by_name['DataSourceService'] = _DATASOURCESERVICE

# @@protoc_insertion_point(module_scope)
