# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/iam/v1beta1/iam_role.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protopia.api.iam.v1beta1 import role_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/iam/v1beta1/iam_role.proto',
  package='protopia.cloud.iam.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'protopia/api/iam/v1beta1/iam_role.proto\x12\x1aprotopia.cloud.iam.v1beta1\x1a#protopia/api/iam/v1beta1/role.proto\"\x1c\n\x0eGetRoleRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1f\n\x11\x44\x65leteRoleRequest\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x12\x44\x65leteRoleResponse\x12\n\n\x02id\x18\x01 \x01(\t\"9\n\x10ListRolesRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"]\n\x11ListRolesResponse\x12/\n\x05roles\x18\x01 \x03(\x0b\x32 .protopia.cloud.iam.v1beta1.Role\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x15\x41\x64\x64RoleMembersRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\"\x18\n\x16\x41\x64\x64RoleMembersResponse\":\n\x17RemoveRoleMemberRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0e\n\x06member\x18\x02 \x01(\t\"\x1a\n\x18RemoveRoleMemberResponse2\x83\x05\n\x07IAMRole\x12P\n\nUpsertRole\x12 .protopia.cloud.iam.v1beta1.Role\x1a .protopia.cloud.iam.v1beta1.Role\x12W\n\x07GetRole\x12*.protopia.cloud.iam.v1beta1.GetRoleRequest\x1a .protopia.cloud.iam.v1beta1.Role\x12k\n\nDeleteRole\x12-.protopia.cloud.iam.v1beta1.DeleteRoleRequest\x1a..protopia.cloud.iam.v1beta1.DeleteRoleResponse\x12h\n\tListRoles\x12,.protopia.cloud.iam.v1beta1.ListRolesRequest\x1a-.protopia.cloud.iam.v1beta1.ListRolesResponse\x12w\n\x0e\x41\x64\x64RoleMembers\x12\x31.protopia.cloud.iam.v1beta1.AddRoleMembersRequest\x1a\x32.protopia.cloud.iam.v1beta1.AddRoleMembersResponse\x12}\n\x10RemoveRoleMember\x12\x33.protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest\x1a\x34.protopia.cloud.iam.v1beta1.RemoveRoleMemberResponseB6Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iamb\x06proto3'
  ,
  dependencies=[protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.DESCRIPTOR,])




_GETROLEREQUEST = _descriptor.Descriptor(
  name='GetRoleRequest',
  full_name='protopia.cloud.iam.v1beta1.GetRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.GetRoleRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=136,
)


_DELETEROLEREQUEST = _descriptor.Descriptor(
  name='DeleteRoleRequest',
  full_name='protopia.cloud.iam.v1beta1.DeleteRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.DeleteRoleRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=169,
)


_DELETEROLERESPONSE = _descriptor.Descriptor(
  name='DeleteRoleResponse',
  full_name='protopia.cloud.iam.v1beta1.DeleteRoleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.DeleteRoleResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=203,
)


_LISTROLESREQUEST = _descriptor.Descriptor(
  name='ListRolesRequest',
  full_name='protopia.cloud.iam.v1beta1.ListRolesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.iam.v1beta1.ListRolesRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.iam.v1beta1.ListRolesRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=262,
)


_LISTROLESRESPONSE = _descriptor.Descriptor(
  name='ListRolesResponse',
  full_name='protopia.cloud.iam.v1beta1.ListRolesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='protopia.cloud.iam.v1beta1.ListRolesResponse.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.iam.v1beta1.ListRolesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=357,
)


_ADDROLEMEMBERSREQUEST = _descriptor.Descriptor(
  name='AddRoleMembersRequest',
  full_name='protopia.cloud.iam.v1beta1.AddRoleMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='protopia.cloud.iam.v1beta1.AddRoleMembersRequest.role_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.iam.v1beta1.AddRoleMembersRequest.members', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=416,
)


_ADDROLEMEMBERSRESPONSE = _descriptor.Descriptor(
  name='AddRoleMembersResponse',
  full_name='protopia.cloud.iam.v1beta1.AddRoleMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=442,
)


_REMOVEROLEMEMBERREQUEST = _descriptor.Descriptor(
  name='RemoveRoleMemberRequest',
  full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest.role_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest.member', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=502,
)


_REMOVEROLEMEMBERRESPONSE = _descriptor.Descriptor(
  name='RemoveRoleMemberResponse',
  full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=530,
)

_LISTROLESRESPONSE.fields_by_name['roles'].message_type = protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE
DESCRIPTOR.message_types_by_name['GetRoleRequest'] = _GETROLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRoleRequest'] = _DELETEROLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRoleResponse'] = _DELETEROLERESPONSE
DESCRIPTOR.message_types_by_name['ListRolesRequest'] = _LISTROLESREQUEST
DESCRIPTOR.message_types_by_name['ListRolesResponse'] = _LISTROLESRESPONSE
DESCRIPTOR.message_types_by_name['AddRoleMembersRequest'] = _ADDROLEMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['AddRoleMembersResponse'] = _ADDROLEMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveRoleMemberRequest'] = _REMOVEROLEMEMBERREQUEST
DESCRIPTOR.message_types_by_name['RemoveRoleMemberResponse'] = _REMOVEROLEMEMBERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRoleRequest = _reflection.GeneratedProtocolMessageType('GetRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROLEREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.GetRoleRequest)
  })
_sym_db.RegisterMessage(GetRoleRequest)

DeleteRoleRequest = _reflection.GeneratedProtocolMessageType('DeleteRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEROLEREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteRoleRequest)
  })
_sym_db.RegisterMessage(DeleteRoleRequest)

DeleteRoleResponse = _reflection.GeneratedProtocolMessageType('DeleteRoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEROLERESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteRoleResponse)
  })
_sym_db.RegisterMessage(DeleteRoleResponse)

ListRolesRequest = _reflection.GeneratedProtocolMessageType('ListRolesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListRolesRequest)
  })
_sym_db.RegisterMessage(ListRolesRequest)

ListRolesResponse = _reflection.GeneratedProtocolMessageType('ListRolesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListRolesResponse)
  })
_sym_db.RegisterMessage(ListRolesResponse)

AddRoleMembersRequest = _reflection.GeneratedProtocolMessageType('AddRoleMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDROLEMEMBERSREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.AddRoleMembersRequest)
  })
_sym_db.RegisterMessage(AddRoleMembersRequest)

AddRoleMembersResponse = _reflection.GeneratedProtocolMessageType('AddRoleMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDROLEMEMBERSRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.AddRoleMembersResponse)
  })
_sym_db.RegisterMessage(AddRoleMembersResponse)

RemoveRoleMemberRequest = _reflection.GeneratedProtocolMessageType('RemoveRoleMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROLEMEMBERREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest)
  })
_sym_db.RegisterMessage(RemoveRoleMemberRequest)

RemoveRoleMemberResponse = _reflection.GeneratedProtocolMessageType('RemoveRoleMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROLEMEMBERRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.RemoveRoleMemberResponse)
  })
_sym_db.RegisterMessage(RemoveRoleMemberResponse)


DESCRIPTOR._options = None

_IAMROLE = _descriptor.ServiceDescriptor(
  name='IAMRole',
  full_name='protopia.cloud.iam.v1beta1.IAMRole',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=533,
  serialized_end=1176,
  methods=[
  _descriptor.MethodDescriptor(
    name='UpsertRole',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.UpsertRole',
    index=0,
    containing_service=None,
    input_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRole',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.GetRole',
    index=1,
    containing_service=None,
    input_type=_GETROLEREQUEST,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRole',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.DeleteRole',
    index=2,
    containing_service=None,
    input_type=_DELETEROLEREQUEST,
    output_type=_DELETEROLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRoles',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.ListRoles',
    index=3,
    containing_service=None,
    input_type=_LISTROLESREQUEST,
    output_type=_LISTROLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddRoleMembers',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.AddRoleMembers',
    index=4,
    containing_service=None,
    input_type=_ADDROLEMEMBERSREQUEST,
    output_type=_ADDROLEMEMBERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveRoleMember',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.RemoveRoleMember',
    index=5,
    containing_service=None,
    input_type=_REMOVEROLEMEMBERREQUEST,
    output_type=_REMOVEROLEMEMBERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IAMROLE)

DESCRIPTOR.services_by_name['IAMRole'] = _IAMROLE

# @@protoc_insertion_point(module_scope)
