# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/tenant/v1beta1/organization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/tenant/v1beta1/organization.proto',
  package='protopia.cloud.tenant.v1beta1',
  syntax='proto3',
  serialized_options=b'Z:github.com/protopia-ai/cloud/pkg/api/tenant/v1beta1;tenant',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.protopia/api/tenant/v1beta1/organization.proto\x12\x1dprotopia.cloud.tenant.v1beta1\x1a google/protobuf/field_mask.proto\"H\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\"$\n\x16GetOrganizationRequest\x12\n\n\x02id\x18\x01 \x01(\t\"A\n\x18ListOrganizationsRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"x\n\x19ListOrganizationsResponse\x12\x42\n\rorganizations\x18\x01 \x03(\x0b\x32+.protopia.cloud.tenant.v1beta1.Organization\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8f\x01\n\x19UpdateOrganizationRequest\x12\x41\n\x0corganization\x18\x01 \x01(\x0b\x32+.protopia.cloud.tenant.v1beta1.Organization\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateOrganizationResponse\"\'\n\x19\x44\x65leteOrganizationRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x1a\x44\x65leteOrganizationResponse\"@\n\x1d\x41\x64\x64OrganizationMembersRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\" \n\x1e\x41\x64\x64OrganizationMembersResponse\"A\n\x1fRemoveOrganizationMemberRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06member\x18\x02 \x01(\t\"\"\n RemoveOrganizationMemberResponse2\xd3\x07\n\x13OrganizationService\x12n\n\x12\x43reateOrganization\x12+.protopia.cloud.tenant.v1beta1.Organization\x1a+.protopia.cloud.tenant.v1beta1.Organization\x12u\n\x0fGetOrganization\x12\x35.protopia.cloud.tenant.v1beta1.GetOrganizationRequest\x1a+.protopia.cloud.tenant.v1beta1.Organization\x12\x86\x01\n\x11ListOrganizations\x12\x37.protopia.cloud.tenant.v1beta1.ListOrganizationsRequest\x1a\x38.protopia.cloud.tenant.v1beta1.ListOrganizationsResponse\x12\x89\x01\n\x12UpdateOrganization\x12\x38.protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest\x1a\x39.protopia.cloud.tenant.v1beta1.UpdateOrganizationResponse\x12\x89\x01\n\x12\x44\x65leteOrganization\x12\x38.protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest\x1a\x39.protopia.cloud.tenant.v1beta1.DeleteOrganizationResponse\x12\x95\x01\n\x16\x41\x64\x64OrganizationMembers\x12<.protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest\x1a=.protopia.cloud.tenant.v1beta1.AddOrganizationMembersResponse\x12\x9b\x01\n\x18RemoveOrganizationMember\x12>.protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest\x1a?.protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberResponseB<Z:github.com/protopia-ai/cloud/pkg/api/tenant/v1beta1;tenantb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_ORGANIZATION = _descriptor.Descriptor(
  name='Organization',
  full_name='protopia.cloud.tenant.v1beta1.Organization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.tenant.v1beta1.Organization.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.tenant.v1beta1.Organization.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='protopia.cloud.tenant.v1beta1.Organization.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.tenant.v1beta1.Organization.members', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=187,
)


_GETORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='GetOrganizationRequest',
  full_name='protopia.cloud.tenant.v1beta1.GetOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.tenant.v1beta1.GetOrganizationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=225,
)


_LISTORGANIZATIONSREQUEST = _descriptor.Descriptor(
  name='ListOrganizationsRequest',
  full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=292,
)


_LISTORGANIZATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOrganizationsResponse',
  full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organizations', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsResponse.organizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=414,
)


_UPDATEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='UpdateOrganizationRequest',
  full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization', full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest.organization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=560,
)


_UPDATEORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='UpdateOrganizationResponse',
  full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=590,
)


_DELETEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='DeleteOrganizationRequest',
  full_name='protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=631,
)


_DELETEORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='DeleteOrganizationResponse',
  full_name='protopia.cloud.tenant.v1beta1.DeleteOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=661,
)


_ADDORGANIZATIONMEMBERSREQUEST = _descriptor.Descriptor(
  name='AddOrganizationMembersRequest',
  full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest.members', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=727,
)


_ADDORGANIZATIONMEMBERSRESPONSE = _descriptor.Descriptor(
  name='AddOrganizationMembersResponse',
  full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=761,
)


_REMOVEORGANIZATIONMEMBERREQUEST = _descriptor.Descriptor(
  name='RemoveOrganizationMemberRequest',
  full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest.member', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=763,
  serialized_end=828,
)


_REMOVEORGANIZATIONMEMBERRESPONSE = _descriptor.Descriptor(
  name='RemoveOrganizationMemberResponse',
  full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=864,
)

_LISTORGANIZATIONSRESPONSE.fields_by_name['organizations'].message_type = _ORGANIZATION
_UPDATEORGANIZATIONREQUEST.fields_by_name['organization'].message_type = _ORGANIZATION
_UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name['Organization'] = _ORGANIZATION
DESCRIPTOR.message_types_by_name['GetOrganizationRequest'] = _GETORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationsRequest'] = _LISTORGANIZATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationsResponse'] = _LISTORGANIZATIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateOrganizationRequest'] = _UPDATEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateOrganizationResponse'] = _UPDATEORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteOrganizationRequest'] = _DELETEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteOrganizationResponse'] = _DELETEORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['AddOrganizationMembersRequest'] = _ADDORGANIZATIONMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['AddOrganizationMembersResponse'] = _ADDORGANIZATIONMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveOrganizationMemberRequest'] = _REMOVEORGANIZATIONMEMBERREQUEST
DESCRIPTOR.message_types_by_name['RemoveOrganizationMemberResponse'] = _REMOVEORGANIZATIONMEMBERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Organization = _reflection.GeneratedProtocolMessageType('Organization', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATION,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.Organization)
  })
_sym_db.RegisterMessage(Organization)

GetOrganizationRequest = _reflection.GeneratedProtocolMessageType('GetOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.GetOrganizationRequest)
  })
_sym_db.RegisterMessage(GetOrganizationRequest)

ListOrganizationsRequest = _reflection.GeneratedProtocolMessageType('ListOrganizationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONSREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.ListOrganizationsRequest)
  })
_sym_db.RegisterMessage(ListOrganizationsRequest)

ListOrganizationsResponse = _reflection.GeneratedProtocolMessageType('ListOrganizationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONSRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.ListOrganizationsResponse)
  })
_sym_db.RegisterMessage(ListOrganizationsResponse)

UpdateOrganizationRequest = _reflection.GeneratedProtocolMessageType('UpdateOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORGANIZATIONREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest)
  })
_sym_db.RegisterMessage(UpdateOrganizationRequest)

UpdateOrganizationResponse = _reflection.GeneratedProtocolMessageType('UpdateOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORGANIZATIONRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.UpdateOrganizationResponse)
  })
_sym_db.RegisterMessage(UpdateOrganizationResponse)

DeleteOrganizationRequest = _reflection.GeneratedProtocolMessageType('DeleteOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGANIZATIONREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest)
  })
_sym_db.RegisterMessage(DeleteOrganizationRequest)

DeleteOrganizationResponse = _reflection.GeneratedProtocolMessageType('DeleteOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGANIZATIONRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.DeleteOrganizationResponse)
  })
_sym_db.RegisterMessage(DeleteOrganizationResponse)

AddOrganizationMembersRequest = _reflection.GeneratedProtocolMessageType('AddOrganizationMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDORGANIZATIONMEMBERSREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest)
  })
_sym_db.RegisterMessage(AddOrganizationMembersRequest)

AddOrganizationMembersResponse = _reflection.GeneratedProtocolMessageType('AddOrganizationMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDORGANIZATIONMEMBERSRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.AddOrganizationMembersResponse)
  })
_sym_db.RegisterMessage(AddOrganizationMembersResponse)

RemoveOrganizationMemberRequest = _reflection.GeneratedProtocolMessageType('RemoveOrganizationMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONMEMBERREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest)
  })
_sym_db.RegisterMessage(RemoveOrganizationMemberRequest)

RemoveOrganizationMemberResponse = _reflection.GeneratedProtocolMessageType('RemoveOrganizationMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONMEMBERRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberResponse)
  })
_sym_db.RegisterMessage(RemoveOrganizationMemberResponse)


DESCRIPTOR._options = None

_ORGANIZATIONSERVICE = _descriptor.ServiceDescriptor(
  name='OrganizationService',
  full_name='protopia.cloud.tenant.v1beta1.OrganizationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=867,
  serialized_end=1846,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.CreateOrganization',
    index=0,
    containing_service=None,
    input_type=_ORGANIZATION,
    output_type=_ORGANIZATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.GetOrganization',
    index=1,
    containing_service=None,
    input_type=_GETORGANIZATIONREQUEST,
    output_type=_ORGANIZATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOrganizations',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.ListOrganizations',
    index=2,
    containing_service=None,
    input_type=_LISTORGANIZATIONSREQUEST,
    output_type=_LISTORGANIZATIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.UpdateOrganization',
    index=3,
    containing_service=None,
    input_type=_UPDATEORGANIZATIONREQUEST,
    output_type=_UPDATEORGANIZATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.DeleteOrganization',
    index=4,
    containing_service=None,
    input_type=_DELETEORGANIZATIONREQUEST,
    output_type=_DELETEORGANIZATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddOrganizationMembers',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.AddOrganizationMembers',
    index=5,
    containing_service=None,
    input_type=_ADDORGANIZATIONMEMBERSREQUEST,
    output_type=_ADDORGANIZATIONMEMBERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOrganizationMember',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.RemoveOrganizationMember',
    index=6,
    containing_service=None,
    input_type=_REMOVEORGANIZATIONMEMBERREQUEST,
    output_type=_REMOVEORGANIZATIONMEMBERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORGANIZATIONSERVICE)

DESCRIPTOR.services_by_name['OrganizationService'] = _ORGANIZATIONSERVICE

# @@protoc_insertion_point(module_scope)
