# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.tenant.v1beta1 import organization_pb2 as protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2


class OrganizationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/CreateOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/GetOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
                )
        self.ListOrganizations = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/ListOrganizations',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsResponse.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/UpdateOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationResponse.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/DeleteOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationResponse.FromString,
                )
        self.AddOrganizationMembers = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/AddOrganizationMembers',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersResponse.FromString,
                )
        self.RemoveOrganizationMember = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/RemoveOrganizationMember',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberResponse.FromString,
                )


class OrganizationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddOrganizationMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveOrganizationMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.GetOrganizationRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
            ),
            'ListOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizations,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationResponse.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationResponse.SerializeToString,
            ),
            'AddOrganizationMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.AddOrganizationMembers,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersResponse.SerializeToString,
            ),
            'RemoveOrganizationMember': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveOrganizationMember,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protopia.cloud.tenant.v1beta1.OrganizationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/CreateOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/GetOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.GetOrganizationRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/ListOrganizations',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/UpdateOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/DeleteOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddOrganizationMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/AddOrganizationMembers',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveOrganizationMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/RemoveOrganizationMember',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
