# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/noise/v1beta1/internal/store.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protopia.api.noise.v1beta1 import distribution_pb2 as protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/noise/v1beta1/internal/store.proto',
  package='',
  syntax='proto3',
  serialized_options=b'ZJgithub.com/protopia-ai/cloud/internal/pkg/api/noise/v1beta1;noise_internal',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/protopia/api/noise/v1beta1/internal/store.proto\x1a-protopia/api/noise/v1beta1/distribution.proto\"\x80\x01\n\x1dStoreNoiseDistributionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12N\n\x0c\x64istribution\x18\x02 \x01(\x0b\x32\x38.protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution\" \n\x1eStoreNoiseDistributionResponse\"A\n RetrieveNoiseDistributionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x0c\n\x04nnid\x18\x02 \x01(\t2\xdc\x01\n\x05Store\x12Y\n\x16StoreNoiseDistribution\x12\x1e.StoreNoiseDistributionRequest\x1a\x1f.StoreNoiseDistributionResponse\x12x\n\x19RetrieveNoiseDistribution\x12!.RetrieveNoiseDistributionRequest\x1a\x38.protopia.cloud.noise.v1beta1.EncryptedNoiseDistributionBLZJgithub.com/protopia-ai/cloud/internal/pkg/api/noise/v1beta1;noise_internalb\x06proto3'
  ,
  dependencies=[protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.DESCRIPTOR,])




_STORENOISEDISTRIBUTIONREQUEST = _descriptor.Descriptor(
  name='StoreNoiseDistributionRequest',
  full_name='StoreNoiseDistributionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='StoreNoiseDistributionRequest.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution', full_name='StoreNoiseDistributionRequest.distribution', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=227,
)


_STORENOISEDISTRIBUTIONRESPONSE = _descriptor.Descriptor(
  name='StoreNoiseDistributionResponse',
  full_name='StoreNoiseDistributionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=261,
)


_RETRIEVENOISEDISTRIBUTIONREQUEST = _descriptor.Descriptor(
  name='RetrieveNoiseDistributionRequest',
  full_name='RetrieveNoiseDistributionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='RetrieveNoiseDistributionRequest.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nnid', full_name='RetrieveNoiseDistributionRequest.nnid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=328,
)

_STORENOISEDISTRIBUTIONREQUEST.fields_by_name['distribution'].message_type = protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2._ENCRYPTEDNOISEDISTRIBUTION
DESCRIPTOR.message_types_by_name['StoreNoiseDistributionRequest'] = _STORENOISEDISTRIBUTIONREQUEST
DESCRIPTOR.message_types_by_name['StoreNoiseDistributionResponse'] = _STORENOISEDISTRIBUTIONRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveNoiseDistributionRequest'] = _RETRIEVENOISEDISTRIBUTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StoreNoiseDistributionRequest = _reflection.GeneratedProtocolMessageType('StoreNoiseDistributionRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORENOISEDISTRIBUTIONREQUEST,
  '__module__' : 'protopia.api.noise.v1beta1.internal.store_pb2'
  # @@protoc_insertion_point(class_scope:StoreNoiseDistributionRequest)
  })
_sym_db.RegisterMessage(StoreNoiseDistributionRequest)

StoreNoiseDistributionResponse = _reflection.GeneratedProtocolMessageType('StoreNoiseDistributionResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORENOISEDISTRIBUTIONRESPONSE,
  '__module__' : 'protopia.api.noise.v1beta1.internal.store_pb2'
  # @@protoc_insertion_point(class_scope:StoreNoiseDistributionResponse)
  })
_sym_db.RegisterMessage(StoreNoiseDistributionResponse)

RetrieveNoiseDistributionRequest = _reflection.GeneratedProtocolMessageType('RetrieveNoiseDistributionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVENOISEDISTRIBUTIONREQUEST,
  '__module__' : 'protopia.api.noise.v1beta1.internal.store_pb2'
  # @@protoc_insertion_point(class_scope:RetrieveNoiseDistributionRequest)
  })
_sym_db.RegisterMessage(RetrieveNoiseDistributionRequest)


DESCRIPTOR._options = None

_STORE = _descriptor.ServiceDescriptor(
  name='Store',
  full_name='Store',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=331,
  serialized_end=551,
  methods=[
  _descriptor.MethodDescriptor(
    name='StoreNoiseDistribution',
    full_name='Store.StoreNoiseDistribution',
    index=0,
    containing_service=None,
    input_type=_STORENOISEDISTRIBUTIONREQUEST,
    output_type=_STORENOISEDISTRIBUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveNoiseDistribution',
    full_name='Store.RetrieveNoiseDistribution',
    index=1,
    containing_service=None,
    input_type=_RETRIEVENOISEDISTRIBUTIONREQUEST,
    output_type=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2._ENCRYPTEDNOISEDISTRIBUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STORE)

DESCRIPTOR.services_by_name['Store'] = _STORE

# @@protoc_insertion_point(module_scope)
