# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/iam/v1beta1/iam_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protopia.api.iam.v1beta1 import policy_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/iam/v1beta1/iam_policy.proto',
  package='protopia.cloud.iam.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)protopia/api/iam/v1beta1/iam_policy.proto\x12\x1aprotopia.cloud.iam.v1beta1\x1a%protopia/api/iam/v1beta1/policy.proto\"[\n\x13SetIamPolicyRequest\x12\x10\n\x08resource\x18\x01 \x01(\t\x12\x32\n\x06policy\x18\x02 \x01(\x0b\x32\".protopia.cloud.iam.v1beta1.Policy\"!\n\x13GetIamPolicyRequest\x12\n\n\x02id\x18\x01 \x01(\t\"?\n\x16ListIamPoliciesRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"h\n\x17ListIamPoliciesResponse\x12\x34\n\x08policies\x18\x01 \x03(\x0b\x32\".protopia.cloud.iam.v1beta1.Policy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"$\n\x16\x44\x65leteIamPolicyRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteIamPolicyResponse\"=\n\x19TestIamPermissionsRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"-\n\x1aTestIamPermissionsResponse\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08\x32\xd3\x04\n\tIAMPolicy\x12\x63\n\x0cSetIamPolicy\x12/.protopia.cloud.iam.v1beta1.SetIamPolicyRequest\x1a\".protopia.cloud.iam.v1beta1.Policy\x12\x63\n\x0cGetIamPolicy\x12/.protopia.cloud.iam.v1beta1.GetIamPolicyRequest\x1a\".protopia.cloud.iam.v1beta1.Policy\x12z\n\x0fListIamPolicies\x12\x32.protopia.cloud.iam.v1beta1.ListIamPoliciesRequest\x1a\x33.protopia.cloud.iam.v1beta1.ListIamPoliciesResponse\x12z\n\x0f\x44\x65leteIamPolicy\x12\x32.protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest\x1a\x33.protopia.cloud.iam.v1beta1.DeleteIamPolicyResponse\x12\x83\x01\n\x12TestIamPermissions\x12\x35.protopia.cloud.iam.v1beta1.TestIamPermissionsRequest\x1a\x36.protopia.cloud.iam.v1beta1.TestIamPermissionsResponseB6Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iamb\x06proto3'
  ,
  dependencies=[protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.DESCRIPTOR,])




_SETIAMPOLICYREQUEST = _descriptor.Descriptor(
  name='SetIamPolicyRequest',
  full_name='protopia.cloud.iam.v1beta1.SetIamPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='protopia.cloud.iam.v1beta1.SetIamPolicyRequest.resource', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='protopia.cloud.iam.v1beta1.SetIamPolicyRequest.policy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=203,
)


_GETIAMPOLICYREQUEST = _descriptor.Descriptor(
  name='GetIamPolicyRequest',
  full_name='protopia.cloud.iam.v1beta1.GetIamPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.GetIamPolicyRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=238,
)


_LISTIAMPOLICIESREQUEST = _descriptor.Descriptor(
  name='ListIamPoliciesRequest',
  full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=303,
)


_LISTIAMPOLICIESRESPONSE = _descriptor.Descriptor(
  name='ListIamPoliciesResponse',
  full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policies', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesResponse.policies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=409,
)


_DELETEIAMPOLICYREQUEST = _descriptor.Descriptor(
  name='DeleteIamPolicyRequest',
  full_name='protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=447,
)


_DELETEIAMPOLICYRESPONSE = _descriptor.Descriptor(
  name='DeleteIamPolicyResponse',
  full_name='protopia.cloud.iam.v1beta1.DeleteIamPolicyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=474,
)


_TESTIAMPERMISSIONSREQUEST = _descriptor.Descriptor(
  name='TestIamPermissionsRequest',
  full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsRequest.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsRequest.resource', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=537,
)


_TESTIAMPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='TestIamPermissionsResponse',
  full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed', full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsResponse.allowed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=584,
)

_SETIAMPOLICYREQUEST.fields_by_name['policy'].message_type = protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY
_LISTIAMPOLICIESRESPONSE.fields_by_name['policies'].message_type = protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY
DESCRIPTOR.message_types_by_name['SetIamPolicyRequest'] = _SETIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name['GetIamPolicyRequest'] = _GETIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name['ListIamPoliciesRequest'] = _LISTIAMPOLICIESREQUEST
DESCRIPTOR.message_types_by_name['ListIamPoliciesResponse'] = _LISTIAMPOLICIESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteIamPolicyRequest'] = _DELETEIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name['DeleteIamPolicyResponse'] = _DELETEIAMPOLICYRESPONSE
DESCRIPTOR.message_types_by_name['TestIamPermissionsRequest'] = _TESTIAMPERMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['TestIamPermissionsResponse'] = _TESTIAMPERMISSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetIamPolicyRequest = _reflection.GeneratedProtocolMessageType('SetIamPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETIAMPOLICYREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.SetIamPolicyRequest)
  })
_sym_db.RegisterMessage(SetIamPolicyRequest)

GetIamPolicyRequest = _reflection.GeneratedProtocolMessageType('GetIamPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIAMPOLICYREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.GetIamPolicyRequest)
  })
_sym_db.RegisterMessage(GetIamPolicyRequest)

ListIamPoliciesRequest = _reflection.GeneratedProtocolMessageType('ListIamPoliciesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIAMPOLICIESREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListIamPoliciesRequest)
  })
_sym_db.RegisterMessage(ListIamPoliciesRequest)

ListIamPoliciesResponse = _reflection.GeneratedProtocolMessageType('ListIamPoliciesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIAMPOLICIESRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListIamPoliciesResponse)
  })
_sym_db.RegisterMessage(ListIamPoliciesResponse)

DeleteIamPolicyRequest = _reflection.GeneratedProtocolMessageType('DeleteIamPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIAMPOLICYREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest)
  })
_sym_db.RegisterMessage(DeleteIamPolicyRequest)

DeleteIamPolicyResponse = _reflection.GeneratedProtocolMessageType('DeleteIamPolicyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIAMPOLICYRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteIamPolicyResponse)
  })
_sym_db.RegisterMessage(DeleteIamPolicyResponse)

TestIamPermissionsRequest = _reflection.GeneratedProtocolMessageType('TestIamPermissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTIAMPERMISSIONSREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.TestIamPermissionsRequest)
  })
_sym_db.RegisterMessage(TestIamPermissionsRequest)

TestIamPermissionsResponse = _reflection.GeneratedProtocolMessageType('TestIamPermissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTIAMPERMISSIONSRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.TestIamPermissionsResponse)
  })
_sym_db.RegisterMessage(TestIamPermissionsResponse)


DESCRIPTOR._options = None

_IAMPOLICY = _descriptor.ServiceDescriptor(
  name='IAMPolicy',
  full_name='protopia.cloud.iam.v1beta1.IAMPolicy',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=587,
  serialized_end=1182,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetIamPolicy',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.SetIamPolicy',
    index=0,
    containing_service=None,
    input_type=_SETIAMPOLICYREQUEST,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIamPolicy',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.GetIamPolicy',
    index=1,
    containing_service=None,
    input_type=_GETIAMPOLICYREQUEST,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListIamPolicies',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.ListIamPolicies',
    index=2,
    containing_service=None,
    input_type=_LISTIAMPOLICIESREQUEST,
    output_type=_LISTIAMPOLICIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteIamPolicy',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.DeleteIamPolicy',
    index=3,
    containing_service=None,
    input_type=_DELETEIAMPOLICYREQUEST,
    output_type=_DELETEIAMPOLICYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestIamPermissions',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.TestIamPermissions',
    index=4,
    containing_service=None,
    input_type=_TESTIAMPERMISSIONSREQUEST,
    output_type=_TESTIAMPERMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IAMPOLICY)

DESCRIPTOR.services_by_name['IAMPolicy'] = _IAMPOLICY

# @@protoc_insertion_point(module_scope)
