# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/noise/v1beta1/distribution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/noise/v1beta1/distribution.proto',
  package='protopia.cloud.noise.v1beta1',
  syntax='proto3',
  serialized_options=b'Z8github.com/protopia-ai/cloud/pkg/api/noise/v1beta1;noise',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-protopia/api/noise/v1beta1/distribution.proto\x12\x1cprotopia.cloud.noise.v1beta1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\x1bGetNoiseDistributionRequest\x12\x0c\n\x04nnid\x18\x01 \x01(\t\"\xda\x01\n\x11NoiseDistribution\x12\x0c\n\x04nnid\x18\x01 \x01(\t\x12\x12\n\nlayer_name\x18\x02 \x01(\t\x12\x16\n\x0elayer_position\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12G\n\x07weights\x18\x05 \x03(\x0b\x32\x36.protopia.cloud.noise.v1beta1.NoiseDistribution.Weight\x1a\x34\n\x06Weight\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x01\x12\r\n\x05value\x18\x03 \x01(\x0c\";\n\x1a\x45ncryptedNoiseDistribution\x12\x0c\n\x04nnid\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"\xe7\x01\n\x05Usage\x12\x0c\n\x04nnid\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x04span\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32*.protopia.cloud.noise.v1beta1.Usage.Action\x12\r\n\x05value\x18\x05 \x01(\x01\",\n\x06\x41\x63tion\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x11\n\rNOISE_SAMPLED\x10\x01\"\x15\n\x13NotifyUsageResponse2\xfc\x01\n\x05Noise\x12\x8b\x01\n\x14GetNoiseDistribution\x12\x39.protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest\x1a\x38.protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution\x12\x65\n\x0bNotifyUsage\x12#.protopia.cloud.noise.v1beta1.Usage\x1a\x31.protopia.cloud.noise.v1beta1.NotifyUsageResponseB:Z8github.com/protopia-ai/cloud/pkg/api/noise/v1beta1;noiseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_USAGE_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='protopia.cloud.noise.v1beta1.Usage.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOISE_SAMPLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=659,
  serialized_end=703,
)
_sym_db.RegisterEnumDescriptor(_USAGE_ACTION)


_GETNOISEDISTRIBUTIONREQUEST = _descriptor.Descriptor(
  name='GetNoiseDistributionRequest',
  full_name='protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=187,
)


_NOISEDISTRIBUTION_WEIGHT = _descriptor.Descriptor(
  name='Weight',
  full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight.shape', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=408,
)

_NOISEDISTRIBUTION = _descriptor.Descriptor(
  name='NoiseDistribution',
  full_name='protopia.cloud.noise.v1beta1.NoiseDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_name', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.layer_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_position', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.layer_position', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.weights', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NOISEDISTRIBUTION_WEIGHT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=408,
)


_ENCRYPTEDNOISEDISTRIBUTION = _descriptor.Descriptor(
  name='EncryptedNoiseDistribution',
  full_name='protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=469,
)


_USAGE = _descriptor.Descriptor(
  name='Usage',
  full_name='protopia.cloud.noise.v1beta1.Usage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.Usage.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='protopia.cloud.noise.v1beta1.Usage.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='span', full_name='protopia.cloud.noise.v1beta1.Usage.span', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='protopia.cloud.noise.v1beta1.Usage.action', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='protopia.cloud.noise.v1beta1.Usage.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USAGE_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=703,
)


_NOTIFYUSAGERESPONSE = _descriptor.Descriptor(
  name='NotifyUsageResponse',
  full_name='protopia.cloud.noise.v1beta1.NotifyUsageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=726,
)

_NOISEDISTRIBUTION_WEIGHT.containing_type = _NOISEDISTRIBUTION
_NOISEDISTRIBUTION.fields_by_name['weights'].message_type = _NOISEDISTRIBUTION_WEIGHT
_USAGE.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USAGE.fields_by_name['span'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_USAGE.fields_by_name['action'].enum_type = _USAGE_ACTION
_USAGE_ACTION.containing_type = _USAGE
DESCRIPTOR.message_types_by_name['GetNoiseDistributionRequest'] = _GETNOISEDISTRIBUTIONREQUEST
DESCRIPTOR.message_types_by_name['NoiseDistribution'] = _NOISEDISTRIBUTION
DESCRIPTOR.message_types_by_name['EncryptedNoiseDistribution'] = _ENCRYPTEDNOISEDISTRIBUTION
DESCRIPTOR.message_types_by_name['Usage'] = _USAGE
DESCRIPTOR.message_types_by_name['NotifyUsageResponse'] = _NOTIFYUSAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNoiseDistributionRequest = _reflection.GeneratedProtocolMessageType('GetNoiseDistributionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOISEDISTRIBUTIONREQUEST,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest)
  })
_sym_db.RegisterMessage(GetNoiseDistributionRequest)

NoiseDistribution = _reflection.GeneratedProtocolMessageType('NoiseDistribution', (_message.Message,), {

  'Weight' : _reflection.GeneratedProtocolMessageType('Weight', (_message.Message,), {
    'DESCRIPTOR' : _NOISEDISTRIBUTION_WEIGHT,
    '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
    # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.NoiseDistribution.Weight)
    })
  ,
  'DESCRIPTOR' : _NOISEDISTRIBUTION,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.NoiseDistribution)
  })
_sym_db.RegisterMessage(NoiseDistribution)
_sym_db.RegisterMessage(NoiseDistribution.Weight)

EncryptedNoiseDistribution = _reflection.GeneratedProtocolMessageType('EncryptedNoiseDistribution', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDNOISEDISTRIBUTION,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution)
  })
_sym_db.RegisterMessage(EncryptedNoiseDistribution)

Usage = _reflection.GeneratedProtocolMessageType('Usage', (_message.Message,), {
  'DESCRIPTOR' : _USAGE,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.Usage)
  })
_sym_db.RegisterMessage(Usage)

NotifyUsageResponse = _reflection.GeneratedProtocolMessageType('NotifyUsageResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYUSAGERESPONSE,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.NotifyUsageResponse)
  })
_sym_db.RegisterMessage(NotifyUsageResponse)


DESCRIPTOR._options = None

_NOISE = _descriptor.ServiceDescriptor(
  name='Noise',
  full_name='protopia.cloud.noise.v1beta1.Noise',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=729,
  serialized_end=981,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNoiseDistribution',
    full_name='protopia.cloud.noise.v1beta1.Noise.GetNoiseDistribution',
    index=0,
    containing_service=None,
    input_type=_GETNOISEDISTRIBUTIONREQUEST,
    output_type=_ENCRYPTEDNOISEDISTRIBUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUsage',
    full_name='protopia.cloud.noise.v1beta1.Noise.NotifyUsage',
    index=1,
    containing_service=None,
    input_type=_USAGE,
    output_type=_NOTIFYUSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOISE)

DESCRIPTOR.services_by_name['Noise'] = _NOISE

# @@protoc_insertion_point(module_scope)
