# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/naming/v1beta1/prn.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/naming/v1beta1/prn.proto',
  package='protopia.cloud.naming.v1beta1',
  syntax='proto3',
  serialized_options=b'Z:github.com/protopia-ai/cloud/pkg/api/naming/v1beta1;naming',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%protopia/api/naming/v1beta1/prn.proto\x12\x1dprotopia.cloud.naming.v1beta1\"U\n\x03PRN\x12\x12\n\nenterprise\x18\x01 \x01(\t\x12\x14\n\x0corganization\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\tB<Z:github.com/protopia-ai/cloud/pkg/api/naming/v1beta1;namingb\x06proto3'
)




_PRN = _descriptor.Descriptor(
  name='PRN',
  full_name='protopia.cloud.naming.v1beta1.PRN',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterprise', full_name='protopia.cloud.naming.v1beta1.PRN.enterprise', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization', full_name='protopia.cloud.naming.v1beta1.PRN.organization', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='protopia.cloud.naming.v1beta1.PRN.service', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='protopia.cloud.naming.v1beta1.PRN.resource_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=157,
)

DESCRIPTOR.message_types_by_name['PRN'] = _PRN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PRN = _reflection.GeneratedProtocolMessageType('PRN', (_message.Message,), {
  'DESCRIPTOR' : _PRN,
  '__module__' : 'protopia.api.naming.v1beta1.prn_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.naming.v1beta1.PRN)
  })
_sym_db.RegisterMessage(PRN)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
